use bevy_ecs::system::Resource;
use winit::{
    application::ApplicationHandler,
    event::WindowEvent,
    event_loop::ActiveEventLoop,
    window::{Window, WindowAttributes, WindowId},
};

#[derive(Resource)]
pub struct WindowHandler {
    window_attributes: WindowAttributes,
    window: Option<Box<Window>>,
}

impl WindowHandler {
    pub fn new(window_attributes: WindowAttributes) -> Self {
        Self {
            window_attributes,
            window: None,
        }
    }
}
impl ApplicationHandler for WindowHandler {
    fn resumed(&mut self, event_loop: &ActiveEventLoop) {
        let window = event_loop
            .create_window(self.window_attributes.clone())
            .unwrap();
        self.window = Some(Box::new(window));
    }

    fn window_event(&mut self, event_loop: &ActiveEventLoop, _id: WindowId, event: WindowEvent) {
        match event {
            WindowEvent::CloseRequested => {
                log::debug!("The close button was pressed; stopping");
                event_loop.exit();
            }
            _ => {}
        }
    }
}
