use std::error::Error;
use winit::event_loop::{ControlFlow, EventLoop};

pub mod core;
pub mod game;
pub mod vulkan;

fn main() -> Result<(), Box<dyn Error>> {
    env_logger::init();

    run_old_app()
}

fn run_new_app() -> Result<(), Box<dyn Error>> {
    let mut app = core::app::App::default();
    app.run()
}

fn run_old_app() -> Result<(), Box<dyn Error>> {
    let event_loop = EventLoop::new().unwrap();
    event_loop.set_control_flow(ControlFlow::Poll);

    let vulkan_context = vulkan::vulkan_context::VulkanContext::from(&event_loop);
    let mut app = core::old_app::App::from(vulkan_context);

    event_loop.run_app(&mut app).map_err(Box::new)?;

    Ok(())
}
